<?php
/**
 * Fichier de config locale, SANS INFORMATIONS SENSIBLES.
 */

namespace Application;

use Fichier\Command\Pdf\AjoutPdcShellCommandGs;
use Fichier\Command\Pdf\AjoutPdcShellCommandQpdf;
use Laminas\Log\Logger;

return [
    'sygal' => [
        'page_de_couverture' => [
            'template' => [
                // template .phtml
                'phtml_file_path' => APPLICATION_DIR . '/module/Depot/view/depot/depot/page-de-couverture/pagedecouverture.phtml',
                // feuille de styles
                'css_file_path' => APPLICATION_DIR . '/module/Depot/view/depot/depot/page-de-couverture/pagedecouverture.css',
            ],
        ],
        'archivabilite' => [
            'proxy' => [
                'enabled' => true,
                'proxy_host' => 'http://proxy.unicaen.fr',
                'proxy_port' => 3128,
            ],
        ],
        'depot_version_corrigee' => [
            'resaisir_autorisation_diffusion' => false,
            'resaisir_attestations' => false,
        ],
        'rapport' => [
            'page_de_couverture' => [
                'template' => [
                    // template .phtml
                    'phtml_file_path' => APPLICATION_DIR . '/module/Application/view/application/rapport/page-de-couverture/pagedecouverture.phtml',
                    // feuille de styles
                    'css_file_path' => APPLICATION_DIR . '/module/Application/view/application/rapport/page-de-couverture/pagedecouverture.css',
                ],
            ],
        ],
    ],

    'actualite' => [
        'actif' => false,
        'flux' => "https://www.normandie-univ.fr/feed/?post_type=post&cat=406,448,472",
    ],

    'offre-these' => [
        'actif' => true,
    ],

    'import-api' => [
        // cf. secret.local.php
    ],

    'import' => [
        // cf. secret.local.php
    ],

    'psr_log' => [
        'inscription_resource_logger' => [
            'writers' => [
                'stream' => [
                    'name' => 'stream',
                    'priority' => 1,
                    'options' => [
                        'stream' => '/var/log/sygal.inscription_resource_logger.log',
                        'filters' => Logger::DEBUG,
                    ],
                ],
            ],
        ],
    ],

    'doctrine' => [
        // cf. secret.local.php
    ],

    'cli_config' => [
        // cf. secret.local.php
    ],

    'public_files' => [
        'cache_enabled' => false,
    ],

    'unicaen-shell' => [
        'commands' => [
            AjoutPdcShellCommandGs::class => [
                'executable' => '/usr/bin/gs',
            ],
            AjoutPdcShellCommandQpdf::class => [
                'executable' => '/usr/bin/qpdf',
            ],
        ],
    ],

    'unicaen-app' => [
        'app_infos' => [
            'mentionsLegales'        => "http://www.unicaen.fr/acces-direct/mentions-legales/",
            'informatiqueEtLibertes' => "http://www.unicaen.fr/acces-direct/informatique-et-libertes/",
        ],
        'mail' => [
            // cf. secret.local.php
            'do_not_send' => false,
        ],
        'ldap' => [
            // cf. secret.local.php
        ],
        'maintenance' => [
            // cf. z.maintenance.local.php
        ],
    ],

    'unicaen-ldap' => [
        // pas de LDAP
    ],

    'unicaen-auth' => [
        'shib' => [
            'order' => 1,
            'enabled' => true,
            'description' =>
                "<p><span class='glyphicon glyphicon-info-sign'></span> Cliquez sur le bouton ci-dessous pour accéder à l'authentification via la fédération d'identité.</p>" .
                "<p><strong>Attention !</strong> Si vous possédez à la fois un compte Étudiant et un compte Personnel, vous devrez utiliser " .
                "votre compte <em>Étudiant</em> pour vous authentifier...</p>",
            'simulate' => [
                // cf. secret.local.php
            ],
            'aliases' => [
                // cf. secret.local.php
            ],
            'required_attributes' => [
                // cf. secret.local.php
            ],
            'logout_url' => '/Shibboleth.sso/Logout?return=', // NB: '?return=' semble obligatoire!
            /**
             * Configuration de la stratégie d'extraction (parmi les données d'authentification shibboleth)
             * de l'identifiant à utiliser pour rechercher l'Individu correspondant à l'utilisateur qui vient de
             * s'authentifier.
             */
            'shib_user_id_extractor' => [
                'default' => [
                    ['name' => 'supannEtuId'],
                    ['name' => 'supannEmpId'],
                ],
            ],
        ],
        'local' => [
            'order' => 2,
            'description' => "Utilisez ce formulaire si vous possédez un compte LDAP établissement ou un compte local dédié à l'application.",
            'ldap' => [
                'enabled' => true,
                'log_failures' => true, // activation ou non des logs (via error_log par défaut) à propos des échecs d'authentification LDAP.
            ],
            'db' => [
                'enabled' => true, // doit être activé pour que l'usurpation fonctionne (cf. Authentication/Storage/Db::read()) :-/ todo: faire mieux
            ],
        ],
        'cas' => [
            'order' => 3,
            'enabled' => false,
            'connection' => [
                // pas de CAS
            ]
        ],

        'usurpation_allowed_usernames' => [
            // cf. secret.local.php
        ],
    ],

    'navigation'   => [
        'default' => [
            'home' => [
                'pages' => [
                    'etab' => [
                        'label' => _("Normandie Université"),
                        'title' => _("Page d'accueil du site de Normandie Université"),
                        'uri'   => 'http://www.normandie-univ.fr',
                        'class' => 'logo-etablissement',
                        // NB: Spécifier la classe 'logo-etablissement' sur la page de navigation provoque le "remplacement"
                        //     du label du lien par l'image 'public/logo-etablissement.png' (à créer).
                    ],
                ],
            ],
        ],
    ],
];
